# terminalpycolor

- A simple python library that can be used on designing your Terminal.

## Installation
```
pip install terminalpycolor
```

## Example
```python
from terminalpycolor import Colors
design = Colors()
print(design.red('Hello World'))
```